@@ -5,7 +5,7 @@ from sqlalchemy.sql import exists, select
 
 from networktools.environment import get_env_variable
 from orm_collector import Base
-
+import os
 
 """
 Create Schema Collector
@@ -27,10 +27,10 @@ def create_datawork(engine):
         raise
 
 if __name__=='__main__':
-    user=get_env_variable('COLLECTOR_DBUSER')
-    passw=get_env_variable('COLLECTOR_DBPASS')
-    dbname=get_env_variable('COLLECTOR_DBNAME')
-    hostname=get_env_variable('COLLECTOR_DBHOST')
+    user=os.environ.get('COLLECTOR_DBUSER')
+    passw=os.environ.get('COLLECTOR_DBPASS')
+    dbname=os.environ.get('COLLECTOR_DBNAME')
+    hostname=os.environ.get('COLLECTOR_DBHOST')
     db_engine='postgresql://%s:%s@%s/%s' %(user,passw,hostname,dbname)
     #create engine
     engine = create_engine(db_engine, echo=True)
